"""
This type stub file was generated by pyright.
"""

from typing import ClassVar, TypeVar

from pydantic import BaseModel

"""
This type stub file was generated by pyright.
"""
T = TypeVar("T", bound="TaranisBaseModel")

class TaranisBaseModel(BaseModel):
    _core_endpoint: ClassVar[str]
    _cache_timeout: ClassVar[int]
    _model_name: ClassVar[str] = ...
    _pretty_name: ClassVar[str] = ...
    model_config = ...
    def model_dump(self, *args, **kwargs): ...
